#include "asterisk.h"
 
#include <pjsip.h>
#include <pjsip_ua.h>
#include <pjlib.h>
 
#include "asterisk/res_pjsip.h"
#include "asterisk/res_pjsip_session.h"
#include "asterisk/module.h"
#include "asterisk/pbx.h"
 
/*** MODULEINFO
    <depend>pjproject</depend>
    <depend>res_pjsip</depend>
    <depend>res_pjsip_session</depend>
 ***/
static int options_incoming_request(struct ast_sip_session *session, pjsip_rx_data *rdata)
{
	pjsip_tx_data *tdata;
        pj_status_t status;

	

	status = pjsip_dlg_create_response(session->inv_session->dlg, rdata, 200, NULL,&tdata);
    	if (status != PJ_SUCCESS) {
		ast_log(LOG_ERROR, "Unable to create response (%d)\n", status);
                return status;
	}
        
	struct pjsip_transaction *tsx = pjsip_rdata_get_tsx(rdata);
        pjsip_dlg_send_response(session->inv_session->dlg, tsx, tdata);

	return PJ_TRUE;
}
 
static struct ast_sip_session_supplement  dlg_options_supplement = {
    .method = "OPTIONS",
    .incoming_request = options_incoming_request,
};
 
static int load_module(void)
{
    if (ast_sip_session_register_supplement(&dlg_options_supplement)) {
        return AST_MODULE_LOAD_DECLINE;
    }
    return AST_MODULE_LOAD_SUCCESS;
}
 
static int unload_module(void)
{
    ast_sip_session_unregister_supplement(&dlg_options_supplement);
    return 0;
}
 
AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_LOAD_ORDER, "SIP OPTIONS in dialog handler",
        .load = load_module,
        .unload = unload_module,
        .load_pri = AST_MODPRI_APP_DEPEND,
           );
